@@ -7,7 +7,7 @@ def prev_dropdown_next(description, options, on_change):
         def on_next(b):
             dropdown.value = (dropdown.value + 1) % len(dropdown.options)
         return on_prev, on_next
-    dropdown = widgets.Dropdown(
+    dropdown = Dropdown(
         description = description,
         value = 0,
         options = options
@@ -18,4 +18,4 @@ def prev_dropdown_next(description, options, on_change):
     on_prev, on_next = get_prev_next_functions(dropdown)
     prev_button.on_click(on_prev)
     next_button.on_click(on_next)
-    return dropdown, prev_button, next_button
+    return prev_button, dropdown, next_button
