@@ -57,7 +57,3 @@ def create_image_subplots(
     if template is not None:
         fig.update_layout(template=template)
     return fig
-
-plotly.graph_objs.Layout(
-    yaxis=dict(autorange='reversed')
-)
\ No newline at end of file
