@@ -1,3 +1,5 @@
+from PDSUtilities.tensorflow.tvp_split import tvp_split
 from PDSUtilities.tensorflow.view_model import view_model
+from PDSUtilities.tensorflow.plot_history import plot_history
 from PDSUtilities.tensorflow.SequentialWithConcatenations import Concatenation
-from PDSUtilities.tensorflow.SequentialWithConcatenations import SequentialWithConcatenations
\ No newline at end of file
+from PDSUtilities.tensorflow.SequentialWithConcatenations import SequentialWithConcatenations
